==> query-exporter-1.1.0.tar.gz: query-exporter-1.1.0/query_exporter/db.py <==
"""Database wrapper."""

from collections import namedtuple

import asyncpg


class DataBaseError(Exception):
    """A database error."""


class InvalidResultCount(Exception):
    """Number of results from a query don't match metrics count."""

    def __init__(self):
        super().__init__('Wrong result count from the query')


Query = namedtuple(
    'Query', ['name', 'interval', 'databases', 'metrics', 'sql'])


class Query(Query):

    def results(self, records):
        """Return a dict with a tuple of values for each metric."""
        if not records:
            return {}

        if len(self.metrics) != len(records[0]):
            raise InvalidResultCount()
        return dict(zip(self.metrics, zip(*records)))


class DataBase(namedtuple('DataBase', ['name', 'dsn'])):
    """A database to perform Queries."""

    asyncpg = asyncpg  # for testing

    _pool = None

    async def connect(self):
        """Connect to the database."""
        try:
            self._pool = await self.asyncpg.create_pool(self.dsn)
        except Exception as error:
            raise DataBaseError(str(error))

    async def close(self):
        """Close the database connection."""
        if self._pool is None:
            return
        await self._pool.close()
        self._pool = None

    async def execute(self, query):
        """Execute a query."""
        if self._pool is None:
            await self.connect()

        async with self._pool.acquire() as connection:
            async with connection.transaction():
                try:
                    rows = await connection.fetch(query.sql)
                    return query.results(rows)
                except Exception as error:
                    raise DataBaseError(str(error))

==> query-exporter-1.2.1.tar.gz: query-exporter-1.2.1/query_exporter/db.py <==
"""Database wrapper."""

from collections import namedtuple

import sqlalchemy

from sqlalchemy_aio import ASYNCIO_STRATEGY


class DataBaseError(Exception):
    """A database error."""


class InvalidResultCount(Exception):
    """Number of results from a query don't match metrics count."""

    def __init__(self):
        super().__init__('Wrong result count from the query')


Query = namedtuple(
    'Query', ['name', 'interval', 'databases', 'metrics', 'sql'])


class Query(Query):

    def results(self, records):
        """Return a dict with a tuple of values for each metric."""
        if not records:
            return {}

        if len(self.metrics) != len(records[0]):
            raise InvalidResultCount()
        return dict(zip(self.metrics, zip(*records)))


class DataBase(namedtuple('DataBase', ['name', 'dsn'])):
    """A database to perform Queries."""

    sqlalchemy = sqlalchemy  # for testing

    _conn = None

    async def connect(self):
        """Connect to the database."""
        try:
            engine = self.sqlalchemy.create_engine(
                self.dsn, strategy=ASYNCIO_STRATEGY)
        except ImportError as error:
            raise DataBaseError('module "{}" not found'.format(error.name))

        try:
            self._conn = await engine.connect()
        except Exception as error:
            raise DataBaseError(str(error).strip())

    async def close(self):
        """Close the database connection."""
        if self._conn is None:
            return
        await self._conn.close()
        self._conn = None

    async def execute(self, query):
        """Execute a query."""
        if self._conn is None:
            await self.connect()

        try:
            result = await self._conn.execute(query.sql)
            return query.results(await result.fetchall())
        except Exception as error:
            raise DataBaseError(str(error).strip())
